# SwaggerClient::HistoricalApi

All URIs are relative to *https://api.discoversnoop.com*

Method | HTTP request | Description
------------- | ------------- | -------------
[**categories_get**](HistoricalApi.md#categories_get) | **GET** /categories | Get historical stats for categories
[**category_get**](HistoricalApi.md#category_get) | **GET** /category | Get history for category ID
[**domain_get**](HistoricalApi.md#domain_get) | **GET** /domain | Get history for domain name
[**domains_get**](HistoricalApi.md#domains_get) | **GET** /domains | Get historical stats for domains
[**page_get**](HistoricalApi.md#page_get) | **GET** /page | Get page history for URL
[**pages_get**](HistoricalApi.md#pages_get) | **GET** /pages | Get historical stats for pages

# **categories_get**
> Array&lt;Categories&gt; categories_get(country, opts)

Get historical stats for categories

### Example
```ruby
# load the gem
require 'swagger_client'
# setup authorization
SwaggerClient.configure do |config|
end

api_instance = SwaggerClient::HistoricalApi.new
country = 'country_example' # String | ISO_3166 country code in 2 letters
opts = { 
  subcountry: 'subcountry_example', # String | state code
  from_date: 'from_date_example', # String | Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience)
  to_date: 'to_date_example', # String | Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience)
  keyword_filter: 'keyword_filter_example', # String | Filter answers to cateogry names containing a particular keyword
  lines: 50, # Integer | Get X results (max in one request is 10K please use offset paginated results if you need more)
  offset: 0 # Integer | Get paginated results from X offset
}

begin
  #Get historical stats for categories
  result = api_instance.categories_get(country, opts)
  p result
rescue SwaggerClient::ApiError => e
  puts "Exception when calling HistoricalApi->categories_get: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **country** | **String**| ISO_3166 country code in 2 letters | 
 **subcountry** | **String**| state code | [optional] 
 **from_date** | **String**| Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 
 **to_date** | **String**| Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 
 **keyword_filter** | **String**| Filter answers to cateogry names containing a particular keyword | [optional] 
 **lines** | **Integer**| Get X results (max in one request is 10K please use offset paginated results if you need more) | [optional] [default to 50]
 **offset** | **Integer**| Get paginated results from X offset | [optional] [default to 0]

### Return type

[**Array&lt;Categories&gt;**](Categories.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **category_get**
> Array&lt;Category&gt; category_get(id, country, opts)

Get history for category ID

### Example
```ruby
# load the gem
require 'swagger_client'
# setup authorization
SwaggerClient.configure do |config|
end

api_instance = SwaggerClient::HistoricalApi.new
id = 'id_example' # String | category id
country = 'country_example' # String | ISO_3166 country code in 2 letters
opts = { 
  subcountry: 'subcountry_example', # String | state code
  from_date: 'from_date_example', # String | Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience)
  to_date: 'to_date_example' # String | Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience)
}

begin
  #Get history for category ID
  result = api_instance.category_get(id, country, opts)
  p result
rescue SwaggerClient::ApiError => e
  puts "Exception when calling HistoricalApi->category_get: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| category id | 
 **country** | **String**| ISO_3166 country code in 2 letters | 
 **subcountry** | **String**| state code | [optional] 
 **from_date** | **String**| Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 
 **to_date** | **String**| Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 

### Return type

[**Array&lt;Category&gt;**](Category.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **domain_get**
> Array&lt;Domain&gt; domain_get(domain, country, opts)

Get history for domain name

### Example
```ruby
# load the gem
require 'swagger_client'
# setup authorization
SwaggerClient.configure do |config|
end

api_instance = SwaggerClient::HistoricalApi.new
domain = 'domain_example' # String | domain name (no subdomain allowed)
country = 'country_example' # String | ISO_3166 country code in 2 letters
opts = { 
  subcountry: 'subcountry_example', # String | state code
  from_date: 'from_date_example', # String | Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience)
  to_date: 'to_date_example' # String | Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience)
}

begin
  #Get history for domain name
  result = api_instance.domain_get(domain, country, opts)
  p result
rescue SwaggerClient::ApiError => e
  puts "Exception when calling HistoricalApi->domain_get: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **domain** | **String**| domain name (no subdomain allowed) | 
 **country** | **String**| ISO_3166 country code in 2 letters | 
 **subcountry** | **String**| state code | [optional] 
 **from_date** | **String**| Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 
 **to_date** | **String**| Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 

### Return type

[**Array&lt;Domain&gt;**](Domain.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **domains_get**
> Array&lt;Domains&gt; domains_get(country, opts)

Get historical stats for domains

### Example
```ruby
# load the gem
require 'swagger_client'
# setup authorization
SwaggerClient.configure do |config|
end

api_instance = SwaggerClient::HistoricalApi.new
country = 'country_example' # String | ISO_3166 country code in 2 letters
opts = { 
  subcountry: 'subcountry_example', # String | state code
  from_date: 'from_date_example', # String | Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience)
  to_date: 'to_date_example', # String | Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience)
  url_filter: 'url_filter_example', # String | Filter answers to domains including a specified string
  lines: 50, # Integer | Get X results (max in one request is 10K please use offset paginated results if you need more)
  offset: 0 # Integer | Get paginated results from X offset
}

begin
  #Get historical stats for domains
  result = api_instance.domains_get(country, opts)
  p result
rescue SwaggerClient::ApiError => e
  puts "Exception when calling HistoricalApi->domains_get: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **country** | **String**| ISO_3166 country code in 2 letters | 
 **subcountry** | **String**| state code | [optional] 
 **from_date** | **String**| Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 
 **to_date** | **String**| Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 
 **url_filter** | **String**| Filter answers to domains including a specified string | [optional] 
 **lines** | **Integer**| Get X results (max in one request is 10K please use offset paginated results if you need more) | [optional] [default to 50]
 **offset** | **Integer**| Get paginated results from X offset | [optional] [default to 0]

### Return type

[**Array&lt;Domains&gt;**](Domains.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **page_get**
> Array&lt;Page&gt; page_get(url, country, opts)

Get page history for URL

### Example
```ruby
# load the gem
require 'swagger_client'
# setup authorization
SwaggerClient.configure do |config|
end

api_instance = SwaggerClient::HistoricalApi.new
url = 'url_example' # String | Fully qualified page url. URL needs to be URL encoded
country = 'country_example' # String | ISO_3166 country code in 2 letters
opts = { 
  subcountry: 'subcountry_example', # String | state code
  from_date: 'from_date_example', # String | Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience)
  to_date: 'to_date_example' # String | Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience)
}

begin
  #Get page history for URL
  result = api_instance.page_get(url, country, opts)
  p result
rescue SwaggerClient::ApiError => e
  puts "Exception when calling HistoricalApi->page_get: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **url** | **String**| Fully qualified page url. URL needs to be URL encoded | 
 **country** | **String**| ISO_3166 country code in 2 letters | 
 **subcountry** | **String**| state code | [optional] 
 **from_date** | **String**| Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 
 **to_date** | **String**| Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional] 

### Return type

[**Array&lt;Page&gt;**](Page.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **pages_get**
> Array&lt;Pages&gt; pages_get(preset_filter, opts)

Get historical stats for pages

### Example
```ruby
# load the gem
require 'swagger_client'
# setup authorization
SwaggerClient.configure do |config|
end

api_instance = SwaggerClient::HistoricalApi.new
preset_filter = 56 # Integer | Apply preset filters => 0 no filter 1 no newsstories 2 only newsstories 3 only sapphire 4 only moonstone 5 sapphire and moonstone combined 6 sapphire or moonstone
opts = { 
  from_date: 'from_date_example', # String | Datas from YYYY-MM-DD (if not provided, last 30 days)
  to_date: 'to_date_example', # String | Datas to YYYY-MM-DD (if not provided, last 30 days)
  country: 'country_example', # String | ISO_3166 country code in 2 letters (if not provided  worldwide)
  subcountry: 'subcountry_example', # String | state code
  domain_filter: 'domain_filter_example', # String | Filter answers to pages of a designated domain name
  url_filter: 'url_filter_example', # String | Filter answers to pages URL including a specified string
  category_filter: 56, # Integer | Filter answers to a specific page category
  keyword_filter: 'keyword_filter_example', # String | Filter answers to pages titles containing a particular keyword
  lines: 50, # Integer | Get X results (max in one request is 50 please use offset paginated results if you need more)
  offset: 0 # Integer | Get paginated results from X offset
}

begin
  #Get historical stats for pages
  result = api_instance.pages_get(preset_filter, opts)
  p result
rescue SwaggerClient::ApiError => e
  puts "Exception when calling HistoricalApi->pages_get: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **preset_filter** | **Integer**| Apply preset filters &#x3D;&gt; 0 no filter 1 no newsstories 2 only newsstories 3 only sapphire 4 only moonstone 5 sapphire and moonstone combined 6 sapphire or moonstone | 
 **from_date** | **String**| Datas from YYYY-MM-DD (if not provided, last 30 days) | [optional] 
 **to_date** | **String**| Datas to YYYY-MM-DD (if not provided, last 30 days) | [optional] 
 **country** | **String**| ISO_3166 country code in 2 letters (if not provided  worldwide) | [optional] 
 **subcountry** | **String**| state code | [optional] 
 **domain_filter** | **String**| Filter answers to pages of a designated domain name | [optional] 
 **url_filter** | **String**| Filter answers to pages URL including a specified string | [optional] 
 **category_filter** | **Integer**| Filter answers to a specific page category | [optional] 
 **keyword_filter** | **String**| Filter answers to pages titles containing a particular keyword | [optional] 
 **lines** | **Integer**| Get X results (max in one request is 50 please use offset paginated results if you need more) | [optional] [default to 50]
 **offset** | **Integer**| Get paginated results from X offset | [optional] [default to 0]

### Return type

[**Array&lt;Pages&gt;**](Pages.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



