# SwaggerClient::LiveApi

All URIs are relative to *https://api.discoversnoop.com*

Method | HTTP request | Description
------------- | ------------- | -------------
[**livecategories_get**](LiveApi.md#livecategories_get) | **GET** /livecategories | Get livedata stats for categories
[**livedomains_get**](LiveApi.md#livedomains_get) | **GET** /livedomains | Get livedata stats for domains
[**livepages_get**](LiveApi.md#livepages_get) | **GET** /livepages | Get livedata stats for pages

# **livecategories_get**
> Array&lt;Categories&gt; livecategories_get(country, opts)

Get livedata stats for categories

### Example
```ruby
# load the gem
require 'swagger_client'
# setup authorization
SwaggerClient.configure do |config|
end

api_instance = SwaggerClient::LiveApi.new
country = 'country_example' # String | ISO_3166 country code in 2 letters
opts = { 
  subcountry: 'subcountry_example', # String | state code
  hours: 56, # Integer | Get results for last x hours
  keyword_filter: 'keyword_filter_example', # String | Filter answers to category names containing a particular keyword
  language_filter: 'language_filter_example', # String | Filter answers to pages in specific user language
  lines: 50, # Integer | Get X results (max in one request is 10K please use offset paginated results if you need more)
  offset: 0 # Integer | Get paginated results from X offset
}

begin
  #Get livedata stats for categories
  result = api_instance.livecategories_get(country, opts)
  p result
rescue SwaggerClient::ApiError => e
  puts "Exception when calling LiveApi->livecategories_get: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **country** | **String**| ISO_3166 country code in 2 letters | 
 **subcountry** | **String**| state code | [optional] 
 **hours** | **Integer**| Get results for last x hours | [optional] 
 **keyword_filter** | **String**| Filter answers to category names containing a particular keyword | [optional] 
 **language_filter** | **String**| Filter answers to pages in specific user language | [optional] 
 **lines** | **Integer**| Get X results (max in one request is 10K please use offset paginated results if you need more) | [optional] [default to 50]
 **offset** | **Integer**| Get paginated results from X offset | [optional] [default to 0]

### Return type

[**Array&lt;Categories&gt;**](Categories.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **livedomains_get**
> Array&lt;Domains&gt; livedomains_get(country, opts)

Get livedata stats for domains

### Example
```ruby
# load the gem
require 'swagger_client'
# setup authorization
SwaggerClient.configure do |config|
end

api_instance = SwaggerClient::LiveApi.new
country = 'country_example' # String | ISO_3166 country code in 2 letters
opts = { 
  subcountry: 'subcountry_example', # String | state code
  url_filter: 'url_filter_example', # String | Filter answers to domains including a specified string
  hours: 56, # Integer | Get results for last x hours
  lines: 50, # Integer | Get X results (max in one request is 10K please use offset paginated results if you need more)
  language_filter: 'language_filter_example', # String | Filter answers to pages in specific user language
  offset: 0 # Integer | Get paginated results from X offset
}

begin
  #Get livedata stats for domains
  result = api_instance.livedomains_get(country, opts)
  p result
rescue SwaggerClient::ApiError => e
  puts "Exception when calling LiveApi->livedomains_get: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **country** | **String**| ISO_3166 country code in 2 letters | 
 **subcountry** | **String**| state code | [optional] 
 **url_filter** | **String**| Filter answers to domains including a specified string | [optional] 
 **hours** | **Integer**| Get results for last x hours | [optional] 
 **lines** | **Integer**| Get X results (max in one request is 10K please use offset paginated results if you need more) | [optional] [default to 50]
 **language_filter** | **String**| Filter answers to pages in specific user language | [optional] 
 **offset** | **Integer**| Get paginated results from X offset | [optional] [default to 0]

### Return type

[**Array&lt;Domains&gt;**](Domains.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **livepages_get**
> Array&lt;Pages&gt; livepages_get(country, preset_filter, opts)

Get livedata stats for pages

### Example
```ruby
# load the gem
require 'swagger_client'
# setup authorization
SwaggerClient.configure do |config|
end

api_instance = SwaggerClient::LiveApi.new
country = 'country_example' # String | ISO_3166 country code in 2 letters
preset_filter = 56 # Integer | Apply preset filters => 0 no filter 1 no newsstories 2 only newsstories 3 only sapphire 4 only moonstone 5 sapphire and moonstone combined 6 sapphire or moonstone
opts = { 
  subcountry: 'subcountry_example', # String | state code
  hours: 56, # Integer | Get results for last x hours
  only_new: 0, # Integer | Get only pages first seen in the reporting period if set on 1
  domain_filter: 'domain_filter_example', # String | Filter answers to pages of a designated domain name
  keyword_filter: 'keyword_filter_example', # String | Filter answers to pages titles containing a particular keyword
  url_filter: 'url_filter_example', # String | Filter answers to pages URL including a specified string
  category_filter: 56, # Integer | Filter answers to pages of a designated category id
  language_filter: 'language_filter_example', # String | Filter answers to pages in specific user language
  lines: 50, # Integer | Get X results (max in one request is 50 please use offset paginated results if you need more)
  offset: 0 # Integer | Get paginated results from X offset
}

begin
  #Get livedata stats for pages
  result = api_instance.livepages_get(country, preset_filter, opts)
  p result
rescue SwaggerClient::ApiError => e
  puts "Exception when calling LiveApi->livepages_get: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **country** | **String**| ISO_3166 country code in 2 letters | 
 **preset_filter** | **Integer**| Apply preset filters &#x3D;&gt; 0 no filter 1 no newsstories 2 only newsstories 3 only sapphire 4 only moonstone 5 sapphire and moonstone combined 6 sapphire or moonstone | 
 **subcountry** | **String**| state code | [optional] 
 **hours** | **Integer**| Get results for last x hours | [optional] 
 **only_new** | **Integer**| Get only pages first seen in the reporting period if set on 1 | [optional] [default to 0]
 **domain_filter** | **String**| Filter answers to pages of a designated domain name | [optional] 
 **keyword_filter** | **String**| Filter answers to pages titles containing a particular keyword | [optional] 
 **url_filter** | **String**| Filter answers to pages URL including a specified string | [optional] 
 **category_filter** | **Integer**| Filter answers to pages of a designated category id | [optional] 
 **language_filter** | **String**| Filter answers to pages in specific user language | [optional] 
 **lines** | **Integer**| Get X results (max in one request is 50 please use offset paginated results if you need more) | [optional] [default to 50]
 **offset** | **Integer**| Get paginated results from X offset | [optional] [default to 0]

### Return type

[**Array&lt;Pages&gt;**](Pages.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



